@@ -93,6 +93,9 @@ class StickProtocol():
         if preKey:
             PKB["preKey"] = preKey.public
             PKB["preKeyId"] = preKey.keyId
+        else:
+            PKB["preKey"] = None
+            PKB["preKeyId"] = None
         if not isSticky:
             preKey.delete()
         elif preKey:
@@ -138,6 +141,9 @@ class StickProtocol():
                 PKB["preKeyId"] = preKey.keyId
                 preKey.used = True
                 preKey.save()
+            else:
+                PKB["preKey"] = None
+                PKB["preKeyId"] = None
             bundles[id] = PKB
         for id in toBeRemoved:
             users_id.remove(id)
